@@ -1,13 +1,12 @@
-use std::fs;
 use std::path::Path;
 
 use crate::io;
 use crate::task::blocking;
 
-/// Creates a new hard link on the filesystem.
+/// Creates a hard link on the filesystem.
 ///
-/// The `dst` path will be a link pointing to the `src` path. Note that systems often require these
-/// two paths to both be located on the same filesystem.
+/// The `dst` path will be a link pointing to the `src` path. Note that operating systems often
+/// require these two paths to be located on the same filesystem.
 ///
 /// This function is an async version of [`std::fs::hard_link`].
 ///
@@ -15,9 +14,10 @@ use crate::task::blocking;
 ///
 /// # Errors
 ///
-/// An error will be returned in the following situations (not an exhaustive list):
+/// An error will be returned in the following situations:
 ///
-/// * The `src` path is not a file or doesn't exist.
+/// * `src` does not point to an existing file.
+/// * Some other I/O error occurred.
 ///
 /// # Examples
 ///
@@ -33,5 +33,5 @@ use crate::task::blocking;
 pub async fn hard_link<P: AsRef<Path>, Q: AsRef<Path>>(from: P, to: Q) -> io::Result<()> {
     let from = from.as_ref().to_owned();
     let to = to.as_ref().to_owned();
-    blocking::spawn(async move { fs::hard_link(&from, &to) }).await
+    blocking::spawn(async move { std::fs::hard_link(&from, &to) }).await
 }
