@@ -2,8 +2,13 @@
 //!
 //! This module is an async version of [`std::fs`].
 //!
+//! [`os::unix::fs`]: ../os/unix/fs/index.html
 //! [`std::fs`]: https://doc.rust-lang.org/std/fs/index.html
 //!
+//! # Platform-specific extensions
+//!
+//! * Unix: use the [`os::unix::fs`] module.
+//!
 //! # Examples
 //!
 //! Create a new file and write some bytes to it:
@@ -23,15 +28,16 @@
 pub use dir_builder::DirBuilder;
 pub use dir_entry::DirEntry;
 pub use file::File;
+pub use file_type::FileType;
+pub use metadata::Metadata;
 pub use open_options::OpenOptions;
+pub use permissions::Permissions;
 pub use read_dir::ReadDir;
 
-#[doc(inline)]
-pub use std::fs::{FileType, Metadata, Permissions};
-
 pub use canonicalize::canonicalize;
 pub use copy::copy;
 pub use create_dir::create_dir;
+pub use create_dir_all::create_dir_all;
 pub use hard_link::hard_link;
 pub use metadata::metadata;
 pub use read::read;
@@ -49,12 +55,15 @@ pub use write::write;
 mod canonicalize;
 mod copy;
 mod create_dir;
+mod create_dir_all;
 mod dir_builder;
 mod dir_entry;
 mod file;
+mod file_type;
 mod hard_link;
 mod metadata;
 mod open_options;
+mod permissions;
 mod read;
 mod read_dir;
 mod read_link;
