@@ -1,13 +1,11 @@
-use super::read_to_end_internal;
-use crate::future::Future;
-use crate::task::{Context, Poll};
-
-use std::io;
 use std::mem;
 use std::pin::Pin;
 use std::str;
 
-use futures_io::AsyncRead;
+use super::read_to_end_internal;
+use crate::future::Future;
+use crate::io::{self, Read};
+use crate::task::{Context, Poll};
 
 #[doc(hidden)]
 #[allow(missing_debug_implementations)]
@@ -18,7 +16,7 @@ pub struct ReadToStringFuture<'a, T: Unpin + ?Sized> {
     pub(crate) start_len: usize,
 }
 
-impl<T: AsyncRead + Unpin + ?Sized> Future for ReadToStringFuture<'_, T> {
+impl<T: Read + Unpin + ?Sized> Future for ReadToStringFuture<'_, T> {
     type Output = io::Result<usize>;
 
     fn poll(mut self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Self::Output> {
