@@ -1,12 +1,8 @@
-use crate::future::Future;
-use crate::task::{Context, Poll};
-
-use std::io::IoSliceMut;
 use std::pin::Pin;
 
-use futures_io::AsyncRead;
-
-use crate::io;
+use crate::future::Future;
+use crate::io::{self, IoSliceMut, Read};
+use crate::task::{Context, Poll};
 
 #[doc(hidden)]
 #[allow(missing_debug_implementations)]
@@ -15,7 +11,7 @@ pub struct ReadVectoredFuture<'a, T: Unpin + ?Sized> {
     pub(crate) bufs: &'a mut [IoSliceMut<'a>],
 }
 
-impl<T: AsyncRead + Unpin + ?Sized> Future for ReadVectoredFuture<'_, T> {
+impl<T: Read + Unpin + ?Sized> Future for ReadVectoredFuture<'_, T> {
     type Output = io::Result<usize>;
 
     fn poll(mut self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Self::Output> {
