@@ -3,10 +3,9 @@ use std::net::SocketAddr;
 use std::pin::Pin;
 
 use cfg_if::cfg_if;
-use futures_io::{AsyncRead, AsyncWrite};
 
 use crate::future;
-use crate::io;
+use crate::io::{self, Read, Write};
 use crate::net::driver::Watcher;
 use crate::net::ToSocketAddrs;
 use crate::task::blocking;
@@ -285,7 +284,7 @@ impl TcpStream {
     }
 }
 
-impl AsyncRead for TcpStream {
+impl Read for TcpStream {
     fn poll_read(
         self: Pin<&mut Self>,
         cx: &mut Context<'_>,
@@ -303,7 +302,7 @@ impl AsyncRead for TcpStream {
     }
 }
 
-impl AsyncRead for &TcpStream {
+impl Read for &TcpStream {
     fn poll_read(
         self: Pin<&mut Self>,
         cx: &mut Context<'_>,
@@ -313,7 +312,7 @@ impl AsyncRead for &TcpStream {
     }
 }
 
-impl AsyncWrite for TcpStream {
+impl Write for TcpStream {
     fn poll_write(
         self: Pin<&mut Self>,
         cx: &mut Context<'_>,
@@ -339,7 +338,7 @@ impl AsyncWrite for TcpStream {
     }
 }
 
-impl AsyncWrite for &TcpStream {
+impl Write for &TcpStream {
     fn poll_write(
         self: Pin<&mut Self>,
         cx: &mut Context<'_>,
