@@ -55,7 +55,7 @@ cfg_if! {
             /// assert_eq!(addr.is_unnamed(), true);
             /// ```
             pub fn is_unnamed(&self) -> bool {
-                unreachable!()
+                unreachable!("this impl only appears in the rendered docs")
             }
 
             /// Returns the contents of this address if it is a `pathname` address.
@@ -84,13 +84,13 @@ cfg_if! {
             /// assert_eq!(addr.as_pathname(), None);
             /// ```
             pub fn as_pathname(&self) -> Option<&Path> {
-                unreachable!()
+                unreachable!("this impl only appears in the rendered docs")
             }
         }
 
         impl fmt::Debug for SocketAddr {
             fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
-                unreachable!()
+                unreachable!("this impl only appears in the rendered docs")
             }
         }
     } else {
