@@ -21,7 +21,18 @@ pub use crate::io::Read as _;
 pub use crate::io::Seek as _;
 #[doc(no_inline)]
 pub use crate::io::Write as _;
-#[doc(no_inline)]
+#[doc(hidden)]
 pub use crate::stream::Stream;
 #[doc(no_inline)]
 pub use crate::task_local;
+
+#[doc(hidden)]
+pub use crate::io::buf_read::BufReadExt as _;
+#[doc(hidden)]
+pub use crate::io::read::ReadExt as _;
+#[doc(hidden)]
+pub use crate::io::seek::SeekExt as _;
+#[doc(hidden)]
+pub use crate::io::write::WriteExt as _;
+#[doc(hidden)]
+pub use crate::stream::stream::StreamExt as _;
